@@ -1,8 +1,13 @@
 
 
 #' @title Simulate \link[groupedHyperframe:as.groupedHyperframe]{groupedHyperframe}
+#' with One-and-Only-One \link[spatstat.geom]{ppp}-Hypercolumn
 #' 
-#' @param ... see examples, for now
+#' @description
+#' To simulate a \link[groupedHyperframe:as.groupedHyperframe]{groupedHyperframe}
+#' with one-and-only-one \link[spatstat.geom]{ppp}-hypercolumn.
+#' 
+#' @param ... see examples in the vignette, for now
 #' 
 #' @param n \link[base]{integer} \link[base]{vector}, 
 #' numbers of \link[spatstat.geom]{ppp.object}s to generate for each set of parameters
@@ -12,7 +17,10 @@
 #' @param envir \link[base]{environment}
 #' 
 #' @returns 
-#' Function [grouped_rppp()] returns a \link[groupedHyperframe:as.groupedHyperframe]{groupedHyperframe}.
+#' The function [grouped_rppp()] returns a \link[groupedHyperframe:as.groupedHyperframe]{groupedHyperframe}.
+#' 
+#' @references
+#' \url{https://tingtingzhan.quarto.pub/groupedhyperframe/nonS3/grouped_rppp_appx.html}
 #' 
 #' @keywords internal
 #' @importFrom spatstat.geom square hyperframe
@@ -47,22 +55,23 @@ grouped_rppp <- function(
     }) |>
     .mapply(FUN = list, MoreArgs = NULL)
   
-  ppp. <- mapply(FUN = \(n, p) { # p = pars[[1L]]; n = n[1L]
-    list(dots = p, n = n, win = win, element1 = FALSE) |>
-      do.call(what = .rppp, args = _) |>
-      suppressMessages()
-  }, p = pars, n = n, SIMPLIFY = FALSE) |>
+  ppp. <- mapply(
+    FUN = \(n, p) { # p = pars[[1L]]; n = n[1L]
+      list(dots = p, n = n, win = win, element1 = FALSE) |>
+        do.call(what = .rppp, args = _) |>
+        suppressMessages()
+    }, 
+    p = pars, n = n, SIMPLIFY = FALSE
+  ) |>
     unlist(recursive = FALSE)
 
-  g1_ <- seq_along(n)
-  
   ret <- hyperframe(
     ppp = ppp., 
-    g1 = g1_ |> rep(times = n) |> as.factor(),
+    g1 = n |> seq_along() |> rep(times = n) |> as.factor(),
     g2 = n |> lapply(FUN = seq_len) |> unlist() |> as.factor()
   )
   attr(ret, which = 'group') <- '~g1/g2' |> str2lang()
   class(ret) <- c('groupedHyperframe', class(ret))
   return(ret)
   
-}
\ No newline at end of file
+}
